OiRA

Help

1. Preparació
2. Implicació
3. Avaluació
4. Informe
5. Grau d’emplenament 92%

# Estat de Private Security, Grafton Street

## Informació general

Eina utilitzada

  Private Security, Grafton Street

## Certification

### 92% Complete

92% Complete! You've earned a certificate for this tool.

With this certificate, you can apply for a reduction on your company's insurance rates. Learn more about the benefits…

View certificate

## Preguntes respostes per mòdul

Commercial manned guarding - Abby Road

  1 question answered without a risk

  3 answers indicated a risk and have at least one measure defined in the action plan

  2 answers indicated a risk without any measure defined in the action plan

  2 questions were postponed

  2 questions aren't answered yet

  - 1 Correcte
  - 3
  - 2 Actuar
  - 2 Posposat
  - 2 No respost

  #### Riscos d'alta prioritat

  - Lorem ipsum
  - Dolor sit amet
  - Consectetuer vadifrimulus automobilis
Mobile partrolling/intervention after alarm

  7 No respost

  1

  1 Actuar

  1 Posposat

  - 7 No respost
  - 1
  - 1 Actuar
  - 1 Posposat

  #### High priority risks

  - Lorem ipsum
  - Dolor sit amet
  - Consectetuer vadifrimulus automobilis

Scroll to top
Back

## status-certificate.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More